==> zio-aws-apigatewayv2_3-5.17.127.1-sources.jar: zio/aws/apigatewayv2/model/GetDomainNameRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetDomainNameRequest(domainName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest = {
    import GetDomainNameRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
      .builder()
      .domainName(__string.unwrap(domainName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetDomainNameRequest.wrap(buildAwsValue())
}
object GetDomainNameRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetDomainNameRequest =
      zio.aws.apigatewayv2.model.GetDomainNameRequest(domainName)
    def domainName: __string
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ) extends zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly {
    override val domainName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.domainName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ): zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.20.22.2-sources.jar: zio/aws/apigatewayv2/model/GetDomainNameRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetDomainNameRequest(domainName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest = {
    import GetDomainNameRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
      .builder()
      .domainName(domainName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetDomainNameRequest.wrap(buildAwsValue())
}
object GetDomainNameRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetDomainNameRequest =
      zio.aws.apigatewayv2.model.GetDomainNameRequest(domainName)
    def domainName: __string
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ) extends zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly {
    override val domainName: __string = impl.domainName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetDomainNameRequest
  ): zio.aws.apigatewayv2.model.GetDomainNameRequest.ReadOnly = new Wrapper(
    impl
  )
}
